#
# spec file for package celluloid
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   io.github.celluloid_player.Celluloid
Name:           celluloid
Version:        0.22
Release:        bp155.2.11
Summary:        Simple GTK+ frontend for MPV
License:        GPL-3.0-or-later
URL:            https://celluloid-player.github.io/
Source:         https://github.com/celluloid-player/celluloid/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool >= 0.40.6
BuildRequires:  meson >= 0.49.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(gio-2.0) >= 2.44
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.44
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(mpv) >= 1.107
Recommends:     %{name}-lang
Recommends:     youtube-dl
Obsoletes:      gnome-mpv < %{version}
Provides:       gnome-mpv = %{version}

%description
Celluloid is a simple GTK+ frontend for MPV.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}

%files
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_datadir}/glib-2.0/schemas/*.gschema.xml
%{_datadir}/applications/%{_name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{_name}.svg
%{_datadir}/icons/hicolor/symbolic/apps/%{_name}-symbolic.svg
%{_datadir}/metainfo/%{_name}.appdata.xml
%{_datadir}/dbus-1/services/%{_name}.service
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Fri Nov  5 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.22
  * Migrate to GTK4.
  * Add Greek, Korean, Norwegian Bokmål, Occidental, Arabic and
    Urdu translations
  * Add option to show title buttons in fullscreen mode.
  * Add option to present the window when opening files.
  * Change default screenshot filename template to
    FILENAME-TIMESTAMP (%%f-%%P).
  * Fix inaccurate timestamp preview.
* Mon Mar 22 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.21
  * Add Basque translation by @aldatsa.
  * Make the shuffle and loop command line options work properly.
  * Make the main menu button toggleable by pressing F10.
  * Add a setting for always appending opened files to the
    playlist.
  * Allow appending files to playlist by holding shift while
    dropping files onto the video area.
  * Make CSD header bar toggleable via the mpv property "border".
* Sat Sep 19 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.20
  * Make it possible to activate context menu when the playlist
    is empty.
  * Prevent constant resizing of the seek bar due to timestamp
    label resizing as its value changes.
  * Only show a single error dialog when a large number of
    errors occurs in rapid succession.
  * Add menu item for opening folders.
  * Adjust position of UI elements of modal dialogs in non-CSD
    mode to be more consistent with CSD mode.
  * Add support for loading external video tracks.
  * Make playlist shuffle toggleable.
  * Make arrow key bindings work with arrow keys on numpad.
* Wed Apr  8 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.19
  * Adjust the range of volume button based on the value of the
    volume-max property.
  * Retain window maximization state across sessions.
  * Retain loop state across sessions.
  * Implement playlist search.
  * Update the list of shortcuts in Keyboard Shortcuts dialog.
  * Correctly handle quotes and escape sequences in extra mpv
    options.
  * Display time at cursor position when hovering the seek bar.
  * Deprecate --mpv-options. Options starting with --mpv- can be
    used to set mpv options instead. For example, passing
  - -mpv-vf=vflip to Celluloid is equivalent to passing
  - -vf=vflip to mpv.
  * Add support for configuring dead zone, an area in which
    mouse movement will not cause controls to be shown.
  * Make window sizing work correctly with HiDPI displays.
  * Add Finnish translation by Kimmo Kujansuu.
  * Add Slovenian translation by @bertronika.
* Tue Nov  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.18
  * Add Persian translation by @danialbehzadi
  * Add Ukranian translation by @vl-nix
  * Add support for showing/hiding window decorations using the
    mpv option --border
  * Add menu item for opening discs
  * Block cursor autohide when volume popup is open in windowed
    mode
  * Fix crash with mpv 0.30
- Dropped 6fca3f16616f4f46c1647fe4610e57c8c9ae74ff.patch (merged
  upstream)
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Fri Oct 11 2019 Ismail Dönmez <idonmez@suse.com>
- Add 6fca3f16616f4f46c1647fe4610e57c8c9ae74ff.patch from upstream
  to fix a crash with the new libmpv.
- Depend on gettext instead of gettext-runtime-mini to fix TW build
* Thu Aug  8 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.17
  * Rename project to Celluloid
  * Add Turkish translation by @TeknoMobil
  * Add Esperanto translation by @F3nd0
  * Migrate from opengl-cb to the new render API
  * Handle numpad keybindings
  * Handle unicode keybindings
  * Forward media key events to mpv
  * Add dconf key for controlling cursor speed threshold for
    unhiding controls
  * Add option for suppressing playback errors
* Mon Jan 21 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.16
  * Split up the General tab in the preferences dialog
  * Improve behavior when toggling playlist under tiling window
    managers
  * Move app menu items to primary menu
  * Use separate MPRIS DBus connection for each window
  * Add support for MPRIS property LoopStatus
  * Add option --mpv-options for setting arbitrary mpv options
    from the command-line
  Note: from the next release onwards GNOME MPV will be renamed
  Celluloid.
* Sat Sep  8 2018 aloisio@gmx.com
- Update to version 0.15
  * Set default screenshot directory to XDG_PICTURES_DIR
  * Improve handling of --window-scale, --autofit,
  - -autofit-larger, and --autofit-smaller
  * Add command line option for setting WM_ROLE
  * Add context menu item for removing playlist items
  * Add context menu item for copying location of playlist items
- Switch to meson build
* Sat Feb 17 2018 aloisio@gmx.com
- Update to version 0.14
  * Add option to make skip buttons change playlist entries rather
    than chapters
  * Make the file chooser accept non-local locations
  * Add right-click menu entry for looping a single file
  * Handle property change events for fullscreen and window-scale
  * Add option to autohide mouse cursor in windowed mode
* Sat Oct 14 2017 aloisio@gmx.com
- Update to version 0.13: no changelog available
* Mon Jun 12 2017 aloisio@gmx.com
- Update to version 0.12: no changelog available
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 0.11:
  * No changelog available.
* Fri Jul 29 2016 sor.alexei@meowr.ru
- Update to version 0.10:
  * No changelog available.
* Tue May 24 2016 sor.alexei@meowr.ru
- Update to version 0.9:
  * No changelog available.
* Tue May  3 2016 sor.alexei@meowr.ru
- Update to version 0.8.
* Tue Mar 22 2016 sor.alexei@meowr.ru
- Initial package.
